clcm_2stage.RdTreat item parameters as fixed to fit a longitudinal CLCM. The model can have any number of timepoints. The only limitation is the estimation of the posteriors - item parameters are fixed. The CLCM R package requires that count items start at 0
clcm_2stage(dat, clcm.mod, lprior.t1)
| dat | dataframe containing the new item responses you want to fit the model to. |
|---|---|
| clcm.mod | a CLCM model that you already fit (Stage 1). This will have the item parameter estimates, item names, item type, and Q-matrix. |
| lprior | this is the log-prior for timepoint 2. N by L matrix. |