Compute the log of the prior distribution for use in the EM algorithm

compute_lprior(post, K, Z = NULL, type = NULL, reg.formula = NULL)

Arguments

post

posterior distribution

Z

data frame or matrix containing covariates

type

the type of prior distribution - this is selected automatically in the clcm() function depending on what is passed

reg.formula

if a latent regression is estimated, pass the model specification as a character here

Value

matrix of N by 2^K